 function T = timescale(varargin)

% T = TIMESCALE(DATA1,FLAG1,DATA2,FLAG2,...)       Ian Gravagne, 6/9/03
%
% Constructor for timescale (ts) objects. 
%
% Inputs:
% DATAn         An array of numbers that represent a timescale interval. Note that
%               the DATA arrays must be 1 x n "row vectors". 
% FLAGn         A flag, 'c' or 'd', to represent whether the associated interval
%               is continuous or discrete. If flag = 'c', then the numbers in DATA 
%               are a discretization of a continuous interval. If something other than 
%               'c' or 'd' is input, the default is assumed to be 'c' (continuous). 
%
% Output:
% T             A timescale object containing a concatenation of the DATA intervals 
%               along with the type (continuous or discrete) of the intervals.
%
% An alternative calling syntax is T = TIMESCALE(DATA, S) where DATA is a
% vector of data points and S is a timescale size matrix (see TS/SIZE). 
%

% Error Checking

if( (length(varargin) > 1) & mod(length(varargin),2) )
    error('requires 0, 1 or even number of inputs');
end

if( length(varargin) == 1 )
    if(~isa(varargin{1},'timescale'))
        error('If there is one input, it must be a timescale object');
    end
end

% Constructor

if(length(varargin) == 0)                   % Constructor for no input arguments
    
    T = struct('data',[],'type',zeros(2,0));
    T = class(T,'timescale');
    
elseif(length(varargin) == 1)               % Constructor when input is a timescale
    
    T = varargin{1};
    
else                                        % Constructor for manually entered data
    
    T = struct('data',[],'type',[]);
    
    if(ischar(varargin{2}))                     % There are type flags
    
        for k = 1:2:length(varargin)
            data = varargin{k};
            
            if(size(data,1) > 1 | ndims(data) > 2)
                message = ['The data array for interval ',num2str((k+1)/2),' must be size 1 x n.'];
                error(message);
            end
            
            flag = varargin{k+1};
            T.data = [T.data, data];
            T.type = [T.type, [length(T.data);(flag == 'd')]];
            
        end
        
    else                                        % There is a size matrix
        
        S = varargin{2};
        
        if(size(S,1) ~= 2)
            error('Size matrix (argument 2) must be 2 x n');
        end
        
        T.data = varargin{1};
        T.type = varargin{2};
        
    end
    
    T = class(T,'timescale');
end


    